#[repr(transparent)]pub struct P256CompressedPublicKey(pub [u8; 33]);Expand description
Compressed P256 public key, i.e. x coordinate with leading SEC-1 tag byte.
Tuple Fields
0: [u8; 33]Trait Implementations
Sourceimpl<'arbitrary> Arbitrary<'arbitrary> for P256CompressedPublicKey
impl<'arbitrary> Arbitrary<'arbitrary> for P256CompressedPublicKey
Sourcefn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the given unstructured data. Read moreSourcefn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the entirety of the given
unstructured data. Read moreSourceimpl AsRef<[u8]> for P256CompressedPublicKey
impl AsRef<[u8]> for P256CompressedPublicKey
Sourceimpl BorshDeserialize for P256CompressedPublicKey
impl BorshDeserialize for P256CompressedPublicKey
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSchema for P256CompressedPublicKey
impl BorshSchema for P256CompressedPublicKey
Sourcefn declaration() -> Declaration
fn declaration() -> Declaration
Get the name of the type without brackets.
Sourcefn add_definitions_recursively(
definitions: &mut BTreeMap<Declaration, Definition>,
)
fn add_definitions_recursively( definitions: &mut BTreeMap<Declaration, Definition>, )
Recursively, using DFS, add type definitions required for this type.
Type definition partially explains how to serialize/deserialize a type.
Sourceimpl BorshSerialize for P256CompressedPublicKey
impl BorshSerialize for P256CompressedPublicKey
Sourceimpl Clone for P256CompressedPublicKey
impl Clone for P256CompressedPublicKey
Sourcefn clone(&self) -> P256CompressedPublicKey
fn clone(&self) -> P256CompressedPublicKey
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for P256CompressedPublicKey
impl Debug for P256CompressedPublicKey
Sourceimpl<'de> Deserialize<'de> for P256CompressedPublicKey
impl<'de> Deserialize<'de> for P256CompressedPublicKey
Sourcefn deserialize<__D>(deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for P256CompressedPublicKey
impl Display for P256CompressedPublicKey
Sourceimpl<'__derive_more_into> From<&'__derive_more_into P256CompressedPublicKey> for &'__derive_more_into [u8; 33]
impl<'__derive_more_into> From<&'__derive_more_into P256CompressedPublicKey> for &'__derive_more_into [u8; 33]
Sourcefn from(value: &'__derive_more_into P256CompressedPublicKey) -> Self
fn from(value: &'__derive_more_into P256CompressedPublicKey) -> Self
Converts to this type from the input type.
Sourceimpl From<&P256UncompressedPublicKey> for P256CompressedPublicKey
impl From<&P256UncompressedPublicKey> for P256CompressedPublicKey
Sourcefn from(value: &P256UncompressedPublicKey) -> Self
fn from(value: &P256UncompressedPublicKey) -> Self
Compress a public key
Sourceimpl From<&VerifyingKey<NistP256>> for P256CompressedPublicKey
impl From<&VerifyingKey<NistP256>> for P256CompressedPublicKey
Sourceimpl From<P256CompressedPublicKey> for [u8; 33]
impl From<P256CompressedPublicKey> for [u8; 33]
Sourcefn from(value: P256CompressedPublicKey) -> Self
fn from(value: P256CompressedPublicKey) -> Self
Converts to this type from the input type.
Sourceimpl From<P256UncompressedPublicKey> for P256CompressedPublicKey
impl From<P256UncompressedPublicKey> for P256CompressedPublicKey
Sourcefn from(value: P256UncompressedPublicKey) -> Self
fn from(value: P256UncompressedPublicKey) -> Self
Compress a public key
Sourceimpl From<VerifyingKey<NistP256>> for P256CompressedPublicKey
impl From<VerifyingKey<NistP256>> for P256CompressedPublicKey
Sourceimpl FromStr for P256CompressedPublicKey
impl FromStr for P256CompressedPublicKey
Sourceimpl Hash for P256CompressedPublicKey
impl Hash for P256CompressedPublicKey
Sourceimpl JsonSchema for P256CompressedPublicKey
impl JsonSchema for P256CompressedPublicKey
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for P256CompressedPublicKey
impl Ord for P256CompressedPublicKey
Sourcefn cmp(&self, other: &P256CompressedPublicKey) -> Ordering
fn cmp(&self, other: &P256CompressedPublicKey) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for P256CompressedPublicKey
impl PartialEq for P256CompressedPublicKey
Sourcefn eq(&self, other: &P256CompressedPublicKey) -> bool
fn eq(&self, other: &P256CompressedPublicKey) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for P256CompressedPublicKey
impl PartialOrd for P256CompressedPublicKey
Sourceimpl Serialize for P256CompressedPublicKeywhere
Self: Display,
impl Serialize for P256CompressedPublicKeywhere
Self: Display,
Sourceimpl TryFrom<&P256CompressedPublicKey> for VerifyingKey
impl TryFrom<&P256CompressedPublicKey> for VerifyingKey
Sourceimpl TryFrom<P256CompressedPublicKey> for VerifyingKey
impl TryFrom<P256CompressedPublicKey> for VerifyingKey
impl Copy for P256CompressedPublicKey
impl Eq for P256CompressedPublicKey
impl StructuralPartialEq for P256CompressedPublicKey