#[repr(transparent)]pub struct P256Signature(pub [u8; 64]);Expand description
P256 signature
Tuple Fields
0: [u8; 64]Trait Implementations
Sourceimpl<'arbitrary> Arbitrary<'arbitrary> for P256Signature
impl<'arbitrary> Arbitrary<'arbitrary> for P256Signature
Sourcefn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the given unstructured data. Read moreSourcefn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the entirety of the given
unstructured data. Read moreSourceimpl AsRef<[u8]> for P256Signature
impl AsRef<[u8]> for P256Signature
Sourceimpl BorshDeserialize for P256Signature
impl BorshDeserialize for P256Signature
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSchema for P256Signature
impl BorshSchema for P256Signature
Sourcefn declaration() -> Declaration
fn declaration() -> Declaration
Get the name of the type without brackets.
Sourcefn add_definitions_recursively(
definitions: &mut BTreeMap<Declaration, Definition>,
)
fn add_definitions_recursively( definitions: &mut BTreeMap<Declaration, Definition>, )
Recursively, using DFS, add type definitions required for this type.
Type definition partially explains how to serialize/deserialize a type.
Sourceimpl BorshSerialize for P256Signature
impl BorshSerialize for P256Signature
Sourceimpl Clone for P256Signature
impl Clone for P256Signature
Sourcefn clone(&self) -> P256Signature
fn clone(&self) -> P256Signature
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for P256Signature
impl Debug for P256Signature
Sourceimpl<'de> Deserialize<'de> for P256Signature
impl<'de> Deserialize<'de> for P256Signature
Sourcefn deserialize<__D>(deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for P256Signature
impl Display for P256Signature
Sourceimpl<'__derive_more_into> From<&'__derive_more_into P256Signature> for &'__derive_more_into [u8; 64]
impl<'__derive_more_into> From<&'__derive_more_into P256Signature> for &'__derive_more_into [u8; 64]
Sourcefn from(value: &'__derive_more_into P256Signature) -> Self
fn from(value: &'__derive_more_into P256Signature) -> Self
Converts to this type from the input type.
Sourceimpl From<&Signature<NistP256>> for P256Signature
impl From<&Signature<NistP256>> for P256Signature
Sourceimpl From<P256Signature> for [u8; 64]
impl From<P256Signature> for [u8; 64]
Sourcefn from(value: P256Signature) -> Self
fn from(value: P256Signature) -> Self
Converts to this type from the input type.
Sourceimpl From<Signature<NistP256>> for P256Signature
impl From<Signature<NistP256>> for P256Signature
Sourceimpl FromStr for P256Signature
impl FromStr for P256Signature
Sourceimpl Hash for P256Signature
impl Hash for P256Signature
Sourceimpl JsonSchema for P256Signature
impl JsonSchema for P256Signature
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for P256Signature
impl Ord for P256Signature
Sourcefn cmp(&self, other: &P256Signature) -> Ordering
fn cmp(&self, other: &P256Signature) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for P256Signature
impl PartialEq for P256Signature
Sourcefn eq(&self, other: &P256Signature) -> bool
fn eq(&self, other: &P256Signature) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for P256Signature
impl PartialOrd for P256Signature
Sourceimpl Serialize for P256Signaturewhere
Self: Display,
impl Serialize for P256Signaturewhere
Self: Display,
Sourceimpl TryFrom<&P256Signature> for Signature
impl TryFrom<&P256Signature> for Signature
Sourceimpl TryFrom<P256Signature> for Signature
impl TryFrom<P256Signature> for Signature
impl Copy for P256Signature
impl Eq for P256Signature
impl StructuralPartialEq for P256Signature