#[repr(transparent)]pub struct P256UncompressedPublicKey(pub [u8; 64]);Expand description
Uncompressed P256 public key without leading SEC-1 tag byte.
Tuple Fields
0: [u8; 64]Implementations
Sourceimpl P256UncompressedPublicKey
impl P256UncompressedPublicKey
Sourcepub fn compress(&self) -> P256CompressedPublicKey
pub fn compress(&self) -> P256CompressedPublicKey
Compress public key
Examples
assert_eq!(
P256UncompressedPublicKey(hex!("beed8cb2c3622dd5f1ee641f12d88e35f3fb8c6ae081d689008bdaa6af38d4408e9c469c5ca7b59927606ef9ea34ee2335e85dbeaa265ca038b5e2896f34ded0"))
.compress()
.0,
hex!("02beed8cb2c3622dd5f1ee641f12d88e35f3fb8c6ae081d689008bdaa6af38d440"),
);Trait Implementations
Sourceimpl<'arbitrary> Arbitrary<'arbitrary> for P256UncompressedPublicKey
impl<'arbitrary> Arbitrary<'arbitrary> for P256UncompressedPublicKey
Sourcefn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the given unstructured data. Read moreSourcefn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the entirety of the given
unstructured data. Read moreSourceimpl AsRef<[u8]> for P256UncompressedPublicKey
impl AsRef<[u8]> for P256UncompressedPublicKey
Sourceimpl BorshDeserialize for P256UncompressedPublicKey
impl BorshDeserialize for P256UncompressedPublicKey
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSchema for P256UncompressedPublicKey
impl BorshSchema for P256UncompressedPublicKey
Sourcefn declaration() -> Declaration
fn declaration() -> Declaration
Get the name of the type without brackets.
Sourcefn add_definitions_recursively(
definitions: &mut BTreeMap<Declaration, Definition>,
)
fn add_definitions_recursively( definitions: &mut BTreeMap<Declaration, Definition>, )
Recursively, using DFS, add type definitions required for this type.
Type definition partially explains how to serialize/deserialize a type.
Sourceimpl BorshSerialize for P256UncompressedPublicKey
impl BorshSerialize for P256UncompressedPublicKey
Sourceimpl Clone for P256UncompressedPublicKey
impl Clone for P256UncompressedPublicKey
Sourcefn clone(&self) -> P256UncompressedPublicKey
fn clone(&self) -> P256UncompressedPublicKey
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for P256UncompressedPublicKey
impl Debug for P256UncompressedPublicKey
Sourceimpl<'de> Deserialize<'de> for P256UncompressedPublicKey
impl<'de> Deserialize<'de> for P256UncompressedPublicKey
Sourcefn deserialize<__D>(deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for P256UncompressedPublicKey
impl Display for P256UncompressedPublicKey
Sourceimpl<'__derive_more_into> From<&'__derive_more_into P256UncompressedPublicKey> for &'__derive_more_into [u8; 64]
impl<'__derive_more_into> From<&'__derive_more_into P256UncompressedPublicKey> for &'__derive_more_into [u8; 64]
Sourcefn from(value: &'__derive_more_into P256UncompressedPublicKey) -> Self
fn from(value: &'__derive_more_into P256UncompressedPublicKey) -> Self
Converts to this type from the input type.
Sourceimpl From<&P256UncompressedPublicKey> for P256CompressedPublicKey
impl From<&P256UncompressedPublicKey> for P256CompressedPublicKey
Sourcefn from(value: &P256UncompressedPublicKey) -> Self
fn from(value: &P256UncompressedPublicKey) -> Self
Compress a public key
Sourceimpl From<&VerifyingKey<NistP256>> for P256UncompressedPublicKey
impl From<&VerifyingKey<NistP256>> for P256UncompressedPublicKey
Sourceimpl From<P256UncompressedPublicKey> for [u8; 64]
impl From<P256UncompressedPublicKey> for [u8; 64]
Sourcefn from(value: P256UncompressedPublicKey) -> Self
fn from(value: P256UncompressedPublicKey) -> Self
Converts to this type from the input type.
Sourceimpl From<P256UncompressedPublicKey> for P256CompressedPublicKey
impl From<P256UncompressedPublicKey> for P256CompressedPublicKey
Sourcefn from(value: P256UncompressedPublicKey) -> Self
fn from(value: P256UncompressedPublicKey) -> Self
Compress a public key
Sourceimpl From<VerifyingKey<NistP256>> for P256UncompressedPublicKey
impl From<VerifyingKey<NistP256>> for P256UncompressedPublicKey
Sourceimpl FromStr for P256UncompressedPublicKey
impl FromStr for P256UncompressedPublicKey
Sourceimpl Hash for P256UncompressedPublicKey
impl Hash for P256UncompressedPublicKey
Sourceimpl JsonSchema for P256UncompressedPublicKey
impl JsonSchema for P256UncompressedPublicKey
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for P256UncompressedPublicKey
impl Ord for P256UncompressedPublicKey
Sourcefn cmp(&self, other: &P256UncompressedPublicKey) -> Ordering
fn cmp(&self, other: &P256UncompressedPublicKey) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for P256UncompressedPublicKey
impl PartialEq for P256UncompressedPublicKey
Sourcefn eq(&self, other: &P256UncompressedPublicKey) -> bool
fn eq(&self, other: &P256UncompressedPublicKey) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for P256UncompressedPublicKey
impl PartialOrd for P256UncompressedPublicKey
Sourceimpl Serialize for P256UncompressedPublicKeywhere
Self: Display,
impl Serialize for P256UncompressedPublicKeywhere
Self: Display,
Sourceimpl TryFrom<&P256UncompressedPublicKey> for VerifyingKey
impl TryFrom<&P256UncompressedPublicKey> for VerifyingKey
Sourceimpl TryFrom<P256UncompressedPublicKey> for VerifyingKey
impl TryFrom<P256UncompressedPublicKey> for VerifyingKey
impl Copy for P256UncompressedPublicKey
impl Eq for P256UncompressedPublicKey
impl StructuralPartialEq for P256UncompressedPublicKey